==> cost-interface-0.3.2-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/pay/CountryPlaneAdPayVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.pay;

import com.chinayanghe.tpm.cost.vo.out.datadetail.regist.CountryPlaneAdRegistVo;

import java.io.Serializable;
import java.util.Date;

/**
 * 全国面上广告核报
 * CountryPlaneAdPay
 * 数据库表：country_plane_ad_pay
 */
public class CountryPlaneAdPayVo implements Serializable {

    private static final long serialVersionUID = -4251422258450578790L;

    /**对应登记单行项目信息*/
    private CountryPlaneAdRegistVo countryPlaneAdRegistVo;
    /**
     * 
     * 表字段 : country_plane_ad_pay.id
     */
    private Integer id;

    /**
     * 核报单号
     * 表字段 : country_plane_ad_pay.regist_no
     */
    private String registNo;

    /**
     * 核报单行项目号
     */
    private Integer itemNo;

    /**
     * 登记单号
     * 表字段 : country_plane_ad_pay.pay_no
     */
    private String payNo;

    /**
     * 申请单号
     * 表字段 : country_plane_ad_pay.apply_no
     */
    private String applyNo;

    /**
     * 登记单行项目号
     * 表字段 : country_plane_ad_pay.regist_item_no
     */
    private Integer registItemNo;

    /**
     * 费用类型编码
     * 表字段 : country_plane_ad_pay.cost_type_id
     */
    private String costTypeId;

    /**
     * 费用类型名称
     * 表字段 : country_plane_ad_pay.cost_type_name
     */
    private String costTypeName;

    /**
     * 媒体大类
     * 表字段 : country_plane_ad_pay.media_big_code
     */
    private String mediaBigCode;

    /**
     * 媒体大类名称
     * 表字段 : country_plane_ad_pay.media_big_name
     */
    private String mediaBigName;

    /**
     * 媒体小类
     * 表字段 : country_plane_ad_pay.media_small_code
     */
    private String mediaSmallCode;

    /**
     * 媒体小类名称
     * 表字段 : country_plane_ad_pay.media_small_name
     */
    private String mediaSmallName;

    /**
     * 媒体内容
     * 表字段 : country_plane_ad_pay.media_content
     */
    private String mediaContent;

    /**
     * 数量
     * 表字段 : country_plane_ad_pay.count
     */
    private Integer count;

    /**
     * 活动形式
     * 表字段 : country_plane_ad_pay.activity_forms
     */
    private String activityForms;

    /**
     * 核报金额(分)
     * 表字段 : country_plane_ad_pay.pay_amount
     */
    private Long payAmount;

    /**
     * 行项目余额
     * 表字段 : country_plane_ad_pay.item_balance
     */
    private Long itemBalance;

    /**
     * 督查意见
     * 表字段 : country_plane_ad_pay.audit_notes
     */
    private String auditNotes;

    /**
     * 
     * 表字段 : country_plane_ad_pay.create_id
     */
    private String createId;

    /**
     * 
     * 表字段 : country_plane_ad_pay.create_name
     */
    private String createName;

    /**
     * 
     * 表字段 : country_plane_ad_pay.create_date
     */
    private Date createDate;

    /**
     * 
     * 表字段 : country_plane_ad_pay.modify_id
     */
    private String modifyId;

    /**
     * 
     * 表字段 : country_plane_ad_pay.modify_name
     */
    private String modifyName;

    /**
     * 
     * 表字段 : country_plane_ad_pay.modify_date
     */
    private Date modifyDate;

    /**
     * 获取  字段:country_plane_ad_pay.id
     *
     * @return country_plane_ad_pay.id, 
     */
    public Integer getId() {
        return id;
    }

    /**
     * 设置  字段:country_plane_ad_pay.id
     *
     * @param id the value for country_plane_ad_pay.id, 
     */
    public void setId(Integer id) {
        this.id = id;
    }

    /**
     * 获取 核报单号 字段:country_plane_ad_pay.regist_no
     *
     * @return country_plane_ad_pay.regist_no, 核报单号
     */
    public String getRegistNo() {
        return registNo;
    }

    /**
     * 设置 核报单号 字段:country_plane_ad_pay.regist_no
     *
     * @param registNo the value for country_plane_ad_pay.regist_no, 核报单号
     */
    public void setRegistNo(String registNo) {
        this.registNo = registNo;
    }

    public CountryPlaneAdRegistVo getCountryPlaneAdRegistVo() {
        return countryPlaneAdRegistVo;
    }

    public void setCountryPlaneAdRegistVo(CountryPlaneAdRegistVo countryPlaneAdRegistVo) {
        this.countryPlaneAdRegistVo = countryPlaneAdRegistVo;
    }

    public Integer getItemNo() {
        return itemNo;
    }

    public void setItemNo(Integer itemNo) {
        this.itemNo = itemNo;
    }

    /**
     * 获取 登记单号 字段:country_plane_ad_pay.pay_no
     *
     * @return country_plane_ad_pay.pay_no, 登记单号
     */
    public String getPayNo() {
        return payNo;
    }

    /**
     * 设置 登记单号 字段:country_plane_ad_pay.pay_no
     *
     * @param payNo the value for country_plane_ad_pay.pay_no, 登记单号
     */
    public void setPayNo(String payNo) {
        this.payNo = payNo;
    }

    /**
     * 获取 申请单号 字段:country_plane_ad_pay.apply_no
     *
     * @return country_plane_ad_pay.apply_no, 申请单号
     */
    public String getApplyNo() {
        return applyNo;
    }

    /**
     * 设置 申请单号 字段:country_plane_ad_pay.apply_no
     *
     * @param applyNo the value for country_plane_ad_pay.apply_no, 申请单号
     */
    public void setApplyNo(String applyNo) {
        this.applyNo = applyNo;
    }

    /**
     * 获取 登记单行项目号 字段:country_plane_ad_pay.regist_item_no
     *
     * @return country_plane_ad_pay.regist_item_no, 登记单行项目号
     */
    public Integer getRegistItemNo() {
        return registItemNo;
    }

    /**
     * 设置 登记单行项目号 字段:country_plane_ad_pay.regist_item_no
     *
     * @param registItemNo the value for country_plane_ad_pay.regist_item_no, 登记单行项目号
     */
    public void setRegistItemNo(Integer registItemNo) {
        this.registItemNo = registItemNo;
    }

    /**
     * 获取 费用类型编码 字段:country_plane_ad_pay.cost_type_id
     *
     * @return country_plane_ad_pay.cost_type_id, 费用类型编码
     */
    public String getCostTypeId() {
        return costTypeId;
    }

    /**
     * 设置 费用类型编码 字段:country_plane_ad_pay.cost_type_id
     *
     * @param costTypeId the value for country_plane_ad_pay.cost_type_id, 费用类型编码
     */
    public void setCostTypeId(String costTypeId) {
        this.costTypeId = costTypeId;
    }

    /**
     * 获取 费用类型名称 字段:country_plane_ad_pay.cost_type_name
     *
     * @return country_plane_ad_pay.cost_type_name, 费用类型名称
     */
    public String getCostTypeName() {
        return costTypeName;
    }

    /**
     * 设置 费用类型名称 字段:country_plane_ad_pay.cost_type_name
     *
     * @param costTypeName the value for country_plane_ad_pay.cost_type_name, 费用类型名称
     */
    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }

    /**
     * 获取 媒体大类 字段:country_plane_ad_pay.media_big_code
     *
     * @return country_plane_ad_pay.media_big_code, 媒体大类
     */
    public String getMediaBigCode() {
        return mediaBigCode;
    }

    /**
     * 设置 媒体大类 字段:country_plane_ad_pay.media_big_code
     *
     * @param mediaBigCode the value for country_plane_ad_pay.media_big_code, 媒体大类
     */
    public void setMediaBigCode(String mediaBigCode) {
        this.mediaBigCode = mediaBigCode;
    }

    /**
     * 获取 媒体大类名称 字段:country_plane_ad_pay.media_big_name
     *
     * @return country_plane_ad_pay.media_big_name, 媒体大类名称
     */
    public String getMediaBigName() {
        return mediaBigName;
    }

    /**
     * 设置 媒体大类名称 字段:country_plane_ad_pay.media_big_name
     *
     * @param mediaBigName the value for country_plane_ad_pay.media_big_name, 媒体大类名称
     */
    public void setMediaBigName(String mediaBigName) {
        this.mediaBigName = mediaBigName;
    }

    /**
     * 获取 媒体小类 字段:country_plane_ad_pay.media_small_code
     *
     * @return country_plane_ad_pay.media_small_code, 媒体小类
     */
    public String getMediaSmallCode() {
        return mediaSmallCode;
    }

    /**
     * 设置 媒体小类 字段:country_plane_ad_pay.media_small_code
     *
     * @param mediaSmallCode the value for country_plane_ad_pay.media_small_code, 媒体小类
     */
    public void setMediaSmallCode(String mediaSmallCode) {
        this.mediaSmallCode = mediaSmallCode;
    }

    /**
     * 获取 媒体小类名称 字段:country_plane_ad_pay.media_small_name
     *
     * @return country_plane_ad_pay.media_small_name, 媒体小类名称
     */
    public String getMediaSmallName() {
        return mediaSmallName;
    }

    /**
     * 设置 媒体小类名称 字段:country_plane_ad_pay.media_small_name
     *
     * @param mediaSmallName the value for country_plane_ad_pay.media_small_name, 媒体小类名称
     */
    public void setMediaSmallName(String mediaSmallName) {
        this.mediaSmallName = mediaSmallName;
    }

    /**
     * 获取 媒体内容 字段:country_plane_ad_pay.media_content
     *
     * @return country_plane_ad_pay.media_content, 媒体内容
     */
    public String getMediaContent() {
        return mediaContent;
    }

    /**
     * 设置 媒体内容 字段:country_plane_ad_pay.media_content
     *
     * @param mediaContent the value for country_plane_ad_pay.media_content, 媒体内容
     */
    public void setMediaContent(String mediaContent) {
        this.mediaContent = mediaContent;
    }

    /**
     * 获取 数量 字段:country_plane_ad_pay.count
     *
     * @return country_plane_ad_pay.count, 数量
     */
    public Integer getCount() {
        return count;
    }

    /**
     * 设置 数量 字段:country_plane_ad_pay.count
     *
     * @param count the value for country_plane_ad_pay.count, 数量
     */
    public void setCount(Integer count) {
        this.count = count;
    }

    /**
     * 获取 活动形式 字段:country_plane_ad_pay.activity_forms
     *
     * @return country_plane_ad_pay.activity_forms, 活动形式
     */
    public String getActivityForms() {
        return activityForms;
    }

    /**
     * 设置 活动形式 字段:country_plane_ad_pay.activity_forms
     *
     * @param activityForms the value for country_plane_ad_pay.activity_forms, 活动形式
     */
    public void setActivityForms(String activityForms) {
        this.activityForms = activityForms;
    }

    /**
     * 获取 核报金额(分) 字段:country_plane_ad_pay.pay_amount
     *
     * @return country_plane_ad_pay.pay_amount, 核报金额(分)
     */
    public Long getPayAmount() {
        return payAmount;
    }

    /**
     * 设置 核报金额(分) 字段:country_plane_ad_pay.pay_amount
     *
     * @param payAmount the value for country_plane_ad_pay.pay_amount, 核报金额(分)
     */
    public void setPayAmount(Long payAmount) {
        this.payAmount = payAmount;
    }

    /**
     * 获取 行项目余额 字段:country_plane_ad_pay.item_balance
     *
     * @return country_plane_ad_pay.item_balance, 行项目余额
     */
    public Long getItemBalance() {
        return itemBalance;
    }

    /**
     * 设置 行项目余额 字段:country_plane_ad_pay.item_balance
     *
     * @param itemBalance the value for country_plane_ad_pay.item_balance, 行项目余额
     */
    public void setItemBalance(Long itemBalance) {
        this.itemBalance = itemBalance;
    }

    /**
     * 获取 督查意见 字段:country_plane_ad_pay.audit_notes
     *
     * @return country_plane_ad_pay.audit_notes, 督查意见
     */
    public String getAuditNotes() {
        return auditNotes;
    }

    /**
     * 设置 督查意见 字段:country_plane_ad_pay.audit_notes
     *
     * @param auditNotes the value for country_plane_ad_pay.audit_notes, 督查意见
     */
    public void setAuditNotes(String auditNotes) {
        this.auditNotes = auditNotes;
    }

    /**
     * 获取  字段:country_plane_ad_pay.create_id
     *
     * @return country_plane_ad_pay.create_id, 
     */
    public String getCreateId() {
        return createId;
    }

    /**
     * 设置  字段:country_plane_ad_pay.create_id
     *
     * @param createId the value for country_plane_ad_pay.create_id, 
     */
    public void setCreateId(String createId) {
        this.createId = createId;
    }

    /**
     * 获取  字段:country_plane_ad_pay.create_name
     *
     * @return country_plane_ad_pay.create_name, 
     */
    public String getCreateName() {
        return createName;
    }

    /**
     * 设置  字段:country_plane_ad_pay.create_name
     *
     * @param createName the value for country_plane_ad_pay.create_name, 
     */
    public void setCreateName(String createName) {
        this.createName = createName;
    }

    /**
     * 获取  字段:country_plane_ad_pay.create_date
     *
     * @return country_plane_ad_pay.create_date, 
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 设置  字段:country_plane_ad_pay.create_date
     *
     * @param createDate the value for country_plane_ad_pay.create_date, 
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 获取  字段:country_plane_ad_pay.modify_id
     *
     * @return country_plane_ad_pay.modify_id, 
     */
    public String getModifyId() {
        return modifyId;
    }

    /**
     * 设置  字段:country_plane_ad_pay.modify_id
     *
     * @param modifyId the value for country_plane_ad_pay.modify_id, 
     */
    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    /**
     * 获取  字段:country_plane_ad_pay.modify_name
     *
     * @return country_plane_ad_pay.modify_name, 
     */
    public String getModifyName() {
        return modifyName;
    }

    /**
     * 设置  字段:country_plane_ad_pay.modify_name
     *
     * @param modifyName the value for country_plane_ad_pay.modify_name, 
     */
    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    /**
     * 获取  字段:country_plane_ad_pay.modify_date
     *
     * @return country_plane_ad_pay.modify_date, 
     */
    public Date getModifyDate() {
        return modifyDate;
    }

    /**
     * 设置  字段:country_plane_ad_pay.modify_date
     *
     * @param modifyDate the value for country_plane_ad_pay.modify_date, 
     */
    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }
}

==> cost-interface-0.3.5-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/pay/CountryPlaneAdPayVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.pay;

import com.chinayanghe.tpm.cost.vo.out.datadetail.regist.CountryPlaneAdRegistVo;

import java.io.Serializable;
import java.util.Date;

/**
 * 全国面上广告核报
 * CountryPlaneAdPay
 * 数据库表：country_plane_ad_pay
 */
public class CountryPlaneAdPayVo implements Serializable {

    private static final long serialVersionUID = -4251422258450578790L;

    /**对应登记单行项目信息*/
    private CountryPlaneAdRegistVo countryPlaneAdRegistVo;
    /**
     *
     * 表字段 : country_plane_ad_pay.id
     */
    private Integer id;

    /**
     * 行项目号
     * 表字段 : country_plane_ad_pay.unit
     */
    private String itemNo;

    /**
     * 核报单号
     * 表字段 : country_plane_ad_pay.regist_no
     */
    private String registNo;

    /**
     * 登记单号
     * 表字段 : country_plane_ad_pay.pay_no
     */
    private String payNo;

    /**
     * 申请单号
     * 表字段 : country_plane_ad_pay.apply_no
     */
    private String applyNo;

    /**
     * 登记单行项目号
     * 表字段 : country_plane_ad_pay.regist_item_no
     */
    private Integer registItemNo;

    /**
     * 费用类型编码
     * 表字段 : country_plane_ad_pay.cost_type_id
     */
    private String costTypeId;

    /**
     * 费用类型名称
     * 表字段 : country_plane_ad_pay.cost_type_name
     */
    private String costTypeName;

    /**
     * 媒体大类
     * 表字段 : country_plane_ad_pay.media_big_code
     */
    private String mediaBigCode;

    /**
     * 媒体大类名称
     * 表字段 : country_plane_ad_pay.media_big_name
     */
    private String mediaBigName;

    /**
     * 媒体小类
     * 表字段 : country_plane_ad_pay.media_small_code
     */
    private String mediaSmallCode;

    /**
     * 媒体小类名称
     * 表字段 : country_plane_ad_pay.media_small_name
     */
    private String mediaSmallName;

    /**
     * 媒体内容
     * 表字段 : country_plane_ad_pay.media_content
     */
    private String mediaContent;

    /**
     * 数量
     * 表字段 : country_plane_ad_pay.count
     */
    private Integer count;

    /**
     * 活动形式
     * 表字段 : country_plane_ad_pay.activity_forms
     */
    private String activityForms;

    /**
     * 核报金额(分)
     * 表字段 : country_plane_ad_pay.pay_amount
     */
    private Long payAmount;

    /**
     * 行项目余额
     * 表字段 : country_plane_ad_pay.item_balance
     */
    private Long itemBalance;

    /**
     * 督查意见
     * 表字段 : country_plane_ad_pay.audit_notes
     */
    private String auditNotes;

    /**
     *
     * 表字段 : country_plane_ad_pay.create_id
     */
    private String createId;

    /**
     *
     * 表字段 : country_plane_ad_pay.create_name
     */
    private String createName;

    /**
     *
     * 表字段 : country_plane_ad_pay.create_date
     */
    private Date createDate;

    /**
     *
     * 表字段 : country_plane_ad_pay.modify_id
     */
    private String modifyId;

    /**
     *
     * 表字段 : country_plane_ad_pay.modify_name
     */
    private String modifyName;

    /**
     *
     * 表字段 : country_plane_ad_pay.modify_date
     */
    private Date modifyDate;

    public CountryPlaneAdRegistVo getCountryPlaneAdRegistVo() {
        return countryPlaneAdRegistVo;
    }

    public void setCountryPlaneAdRegistVo(CountryPlaneAdRegistVo countryPlaneAdRegistVo) {
        this.countryPlaneAdRegistVo = countryPlaneAdRegistVo;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getItemNo() {
        return itemNo;
    }

    public void setItemNo(String itemNo) {
        this.itemNo = itemNo;
    }

    public String getRegistNo() {
        return registNo;
    }

    public void setRegistNo(String registNo) {
        this.registNo = registNo;
    }

    public String getPayNo() {
        return payNo;
    }

    public void setPayNo(String payNo) {
        this.payNo = payNo;
    }

    public String getApplyNo() {
        return applyNo;
    }

    public void setApplyNo(String applyNo) {
        this.applyNo = applyNo;
    }

    public Integer getRegistItemNo() {
        return registItemNo;
    }

    public void setRegistItemNo(Integer registItemNo) {
        this.registItemNo = registItemNo;
    }

    public String getCostTypeId() {
        return costTypeId;
    }

    public void setCostTypeId(String costTypeId) {
        this.costTypeId = costTypeId;
    }

    public String getCostTypeName() {
        return costTypeName;
    }

    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }

    public String getMediaBigCode() {
        return mediaBigCode;
    }

    public void setMediaBigCode(String mediaBigCode) {
        this.mediaBigCode = mediaBigCode;
    }

    public String getMediaBigName() {
        return mediaBigName;
    }

    public void setMediaBigName(String mediaBigName) {
        this.mediaBigName = mediaBigName;
    }

    public String getMediaSmallCode() {
        return mediaSmallCode;
    }

    public void setMediaSmallCode(String mediaSmallCode) {
        this.mediaSmallCode = mediaSmallCode;
    }

    public String getMediaSmallName() {
        return mediaSmallName;
    }

    public void setMediaSmallName(String mediaSmallName) {
        this.mediaSmallName = mediaSmallName;
    }

    public String getMediaContent() {
        return mediaContent;
    }

    public void setMediaContent(String mediaContent) {
        this.mediaContent = mediaContent;
    }

    public Integer getCount() {
        return count;
    }

    public void setCount(Integer count) {
        this.count = count;
    }

    public String getActivityForms() {
        return activityForms;
    }

    public void setActivityForms(String activityForms) {
        this.activityForms = activityForms;
    }

    public Long getPayAmount() {
        return payAmount;
    }

    public void setPayAmount(Long payAmount) {
        this.payAmount = payAmount;
    }

    public Long getItemBalance() {
        return itemBalance;
    }

    public void setItemBalance(Long itemBalance) {
        this.itemBalance = itemBalance;
    }

    public String getAuditNotes() {
        return auditNotes;
    }

    public void setAuditNotes(String auditNotes) {
        this.auditNotes = auditNotes;
    }

    public String getCreateId() {
        return createId;
    }

    public void setCreateId(String createId) {
        this.createId = createId;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getModifyId() {
        return modifyId;
    }

    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    public String getModifyName() {
        return modifyName;
    }

    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    public Date getModifyDate() {
        return modifyDate;
    }

    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }
}
